Security Advisories (3)
CVE-2007-6341 (2008-02-08)

Allows remote attackers to cause a denial of service (program "croak") via a crafted DNS response.

CVE-2007-3409 (2007-06-26)

Net::DNS before 0.60, a Perl module, allows remote attackers to cause a denial of service (stack consumption) via a malformed compressed DNS packet with self-referencing pointers, which triggers an infinite loop.

CVE-2007-3377 (2007-06-25)

Header.pm in Net::DNS before 0.60, a Perl module, (1) generates predictable sequence IDs with a fixed increment and (2) can use the same starting ID for all child processes of a forking server, which allows remote attackers to spoof DNS responses, as originally reported for qpsmtp and spamassassin.

NAME

Net::DNS::Select - Wrapper Around Select

SYNOPSIS

use Net::DNS::Select;

my $sel = Net::DNS::Select->new;

DESCRIPTION

This class provides a wrapper around IO::Select. On UNIX platforms it simply returns a IO::Select object. On the Windows platform it implements a simple array of handles.

BUGS

The current maintainer does not know if this module is still needed. Feedback from Windows gurus welcome.

COPYRIGHT

Copyright (c) 1997-2002 Michael Fuhr.

Portions Copyright (c) 2002-2003 Chris Reinhardt.

All rights reserved. This program is free software; you may redistribute it and/or modify it under the same terms as Perl itself.

SEE ALSO

perl(1), Net::DNS, Net::DNS::Resolver